@@ -7,26 +7,30 @@ use utf8;
 use warnings qw(all);
 
 use Carp qw(carp);
-use Memoize;
 use Net::Curl::Easy;
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '0.024'; # VERSION
+our $VERSION = '0.025'; # VERSION
 
-memoize($_) for qw(info opt);
 
+our (%const_info, %const_opt);
 
 sub info {
-    return _curl_const(CURLINFO => shift);
+    my ($name) = @_;
+    $const_info{$name} = _curl_const(CURLINFO => $name)
+        unless exists $const_info{$name};
+    return $const_info{$name};
 }
 
 sub opt {
-    return _curl_const(CURLOPT => shift);
+    my ($name) = @_;
+    $const_opt{$name} = _curl_const(CURLOPT => $name)
+        unless exists $const_info{$name};
+    return $const_opt{$name};
 }
 
 sub _curl_const {
     my ($suffix => $key) = @_;
-
     return $key if looks_like_number($key);
 
     $key =~ s{^Net::Curl::Easy::}{}i;
@@ -60,7 +64,7 @@ AnyEvent::Net::Curl::Const - Access Net::Curl::* constants by name
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
